use bevy::prelude::*;

#[derive(Resource, Debug, Default)]
pub struct AssetLoader {
    pub images: Sprites,
    pub sounds: Sounds,
}

#[derive(Resource, Debug, Default)]
pub struct Sprites {
    pub player: Handle<TextureAtlas>,
    pub statue: Handle<TextureAtlas>,
}

#[derive(Resource, Debug, Default)]
pub struct Sounds {
    pub meow: Handle<AudioSource>,
}

pub struct AssetPlugin;

impl Plugin for AssetPlugin {
    fn build(&self, app: &mut App) {
        app.init_resource::<AssetLoader>()
            .add_systems(Startup, load_assets);
    }
}

fn load_assets(
    mut assets: ResMut<AssetLoader>,
    asset_server: Res<AssetServer>,
    mut texture_atlases: ResMut<Assets<TextureAtlas>>,
) {
    let player_img = asset_server.load("img/Player.png");
    let props_img = asset_server.load("img/Props.png");

    let player_atlas = TextureAtlas::from_grid(
        player_img,
        Vec2::new(32.0, 64.0),
        3,
        1,
        Some(Vec2 { x: 0., y: 0. }),
        Some(Vec2 { x: 0., y: 0. }),
    );
    let statue_atlas = TextureAtlas::from_grid(
        props_img,
        Vec2::new(40., 74.),
        1,
        1,
        None,
        Some(Vec2::new(443., 20.)),
    );

    let player_atlas_handle = texture_atlases.add(player_atlas);
    let statue_atlas_handle = texture_atlases.add(statue_atlas);

    *assets = AssetLoader {
        images: Sprites {
            player: player_atlas_handle,
            statue: statue_atlas_handle,
        },

        sounds: Sounds {
            meow: asset_server.load("sfx/meow.wav"),
        },
    };
}
